@@ -2,7 +2,7 @@
 
 __author__ = 'Thomas Bartelmess'
 __email__ = 'tbartelmess@marketcircle.com'
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 __all__ = ['Server']
 
@@ -15,9 +15,6 @@ class Protocol(asyncio.Protocol):
         self.protocol_factory = protocol_factory
         self.processor = processor
 
-    def connection_made(self, transport):
-        self.transport = transport
-
     def process_request(self, input_buffer):
         input_protocol = self.protocol_factory.getProtocol(input_buffer)
         out_buffer = TTransport.TMemoryBuffer()
@@ -25,6 +22,9 @@ class Protocol(asyncio.Protocol):
         self.processor.process(input_protocol, out_protocol)
         self.transport.write(out_buffer.getvalue())
 
+    def connection_made(self, transport):
+        self.transport = transport
+
     def data_received(self, data):
         """
         Callback when data is received.
@@ -45,11 +45,12 @@ class Server(object):
     server_ready_event = None
     server_stop_event = None
 
-    def __init__(self, host, port, protocol_factory, processor):
+    def __init__(self, host, port, protocol_factory, processor, ssl=None):
         self.host = host
         self.port = port
         self.protocol_factory = protocol_factory
         self.processor = processor
+        self.ssl = ssl
 
     def make_protocol(self):
         return Protocol(self.protocol_factory, self.processor)
@@ -57,7 +58,10 @@ class Server(object):
     def serve(self):
         loop = asyncio.get_event_loop()
 
-        coro = loop.create_server(self.make_protocol, self.host, self.port)
+        coro = loop.create_server(self.make_protocol,
+                                  host = self.host,
+                                  port = self.port,
+                                  ssl = self.ssl)
 
         server = loop.run_until_complete(coro)
         if self.server_ready_event:
